#
# spec file for package python-intake
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-intake
Version:        0.7.0
Release:        1.1
Summary:        Data loading and cataloging system
License:        BSD-2-Clause
URL:            https://github.com/intake/intake
Source:         https://github.com/intake/intake/archive/refs/tags/%{version}.tar.gz#/intake-%{version}-gh.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Jinja2
Requires:       python-PyYAML
Requires:       python-appdirs
Requires:       python-dask
Requires:       python-entrypoints
Requires:       python-fsspec >= 2021.7.0
Requires:       python-msgpack
Requires:       python-requests
Recommends:     python-bokeh
Recommends:     python-dask-dataframe
Recommends:     python-hvplot
Recommends:     python-msgpack-numpy
Recommends:     python-panel >= 0.8.0
Recommends:     python-pyarrow
Recommends:     python-python-snappy
Recommends:     python-tornado
Suggests:       python-intake-parquet
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Jinja2}
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module aiohttp}
BuildRequires:  %{python_module appdirs}
BuildRequires:  %{python_module bokeh}
BuildRequires:  %{python_module dask-dataframe}
BuildRequires:  %{python_module dask}
BuildRequires:  %{python_module entrypoints}
BuildRequires:  %{python_module fsspec >= 2021.7.0}
BuildRequires:  %{python_module hvplot >= 0.5.2}
BuildRequires:  %{python_module msgpack}
# strictly a test req, but not a runtime requirement, not available in openSUSE
#BuildRequires:  %%{python_module intake-parquet}
BuildRequires:  %{python_module msgpack-numpy}
BuildRequires:  %{python_module notebook}
BuildRequires:  %{python_module panel >= 0.8.0}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-snappy}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module tornado}
BuildRequires:  %{python_module zarr}
# /SECTION
%python_subpackages

%description
A plugin system for loading your data and making data catalogs.

%prep
%autosetup -p1 -n intake-%{version}
find intake -path '*/tests/*.py' -exec sed -i '1{/env python/d}' {} ';'

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/intake
%python_clone -a %{buildroot}%{_bindir}/intake-server
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_expand chmod a-x %{buildroot}%{$python_sitelib}/intake-%{version}*-info/*

%check
# Looks for `which python`, which we don't have in TW
donttest+=" or test_which"
# test_discover_cli overrides the PYTHONPATH and thus doesn't find the package in buildroot
# test_discover does not find its own config because the registration does not work in our test env
donttest+=" or test_discover"
if [ $(getconf LONG_BIT) -eq 32 ]; then
  # the test looks for the wrong dtype on 32-bit (int64 vs int)
  donttest+=" or test_zarr_minimal"
fi
# skip tests expecting the unavailable intake-parquet driver (configured in intake/tests/catalog_inherit_params.yml)
donttest+=" or test_inherit_params"
donttest+=" or test_runtime_overwrite_params"
donttest+=" or test_local_param_overwrites"
donttest+=" or test_local_and_global_params"
donttest+=" or test_search_inherit_params"
donttest+=" or test_multiple_cats_params"
# wrong exception class
donttest+=" or test_mlist_parameter"
%pytest -ra -k "not (${donttest:4})"

%post
%python_install_alternative intake
%python_install_alternative intake-server

%postun
%python_uninstall_alternative intake
%python_uninstall_alternative intake-server

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/intake-server
%python_alternative %{_bindir}/intake
%{python_sitelib}/intake
%{python_sitelib}/intake-%{version}*-info

%changelog
* Thu Jun  8 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.7.0
  * be able to override arguments when using a source defined in an
    entry-point
  * make sources usable without explicit dependence on dask: zarr,
    textfiles, csv
  * removed some explicit usage (but not all) of dask throughout
    the codebase
  * new dataframe pipeline transform source
- Drop use-sys-executable.patch
* Wed Apr 12 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.6.8:
  * user parameter parsed as string before conversion to given type
  * numpy source becomes first to have read() path avoid dask
  * when registering drivers dynamically, corresponding open_* functions will
    be created automatically (plus refactor/cleanup of the discovery code)
  * catalog .gui attribute will make top-level GUI instance instead of cut
    down one-catalog version
  * server fix for upstream dask change giving newlined in report
  * editable plots, based on hvPlot's "explorer"
  * remove "text" input to YAMLFileCatalog
  * GUI bug fixes
  * allow catalog TTL as None
- Add patch use-sys-executable.patch:
  * Use sys.executable, rather than hardcoding python.
* Wed Nov 23 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.6.6
  * Fixed bug in json and jsonl driver.
  * Ensure description is retained in the catalog.
  * Fix cache issue when running inside a notebook.
  * Add templating parameters.
  * Plotting api keeps hold of hvplot calls to allow other plots to
    be made.
  * docs updates
  * fix urljoin for server via proxy
- Remove manual entrypoint setup for test suite. It istaken care of
  by the %%pytest macro.
* Tue Apr 26 2022 Matej Cepl <mcepl@suse.com>
- Remove skip_python310, it is not needed anymore.
* Thu Feb  3 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.6.5
  * no changelog
- Drop intake-pr601-dask-array.patch merged upstream
- Move to github archive because more tests were removed in the
  sdist
- Avoid tests with optional intake-parquet driver: New package
  would require significant effort including pyarrow
* Mon Jul 19 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.6.2
  * no changelog
- Drop intake-pr560-fix-category-ordering.patch merged upstream
- Add intake-pr601-dask-array.patch for dask API change
  gh#intake/intake#601
* Sat Feb 13 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.6.0
  * no changelog
- Skip python36 build: Packages depening on numpy are in the
  dependency tree (NEP 29)
- Add test files
  * tests-data.zarr.0
  * tests-data.zarr.zarray
  * calvert_uk_filter.tar.gz
- Add intake-pr560-fix-category-ordering.patch gh#intake/intake#560
  in order to support newer dask versions
* Mon May 25 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Jan 30 2020 Todd R <toddrme2178@gmail.com>
- Update to 0.5.4
  * Allow for hvplot returning dynamic layouts
  * Make sure that ttl is numeric
  * add intake-nested-yaml-catalog plugin
  * check_meta_flag -> verify_meta
  * forgot to add pickle & json
  * fix dask version constraint
  * Don't replace "inteke" in remote server name
  * Update intake/gui/source/defined_plots.py
  * Use a generator for pagination.
  * add address to log
  * add server cli kwarg for address
  * dask.bytes to fsspec
  * don't check meta when merging dataframes
  * pin fsspec >= 0.3.6
  * return storage options if given
  * update open_file link
  * use the given encoder if not in the list
  * verify kwarg and dask version check
* Tue Nov 19 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.5.3
  * use frombuffer (fromstring is depr)
  * fix npy source
  * make example using storge_options usable
  * update docs around storage_options
  * Don't necessarily pass storage_options
  * fix with test
  * Add setup entrypoints for drivers and tidy CLI
  * Don't warn twice
  * Add drivers CLI test
  * update test
  * Add a load of tests
  * Fix msgpack imports so msgpack_numpy is not required.
  * ian-r-rose committed on Jul 26
  * Use master dask on pip build too
  * Don't import msgpack_numpy unless needed
  * prefer conda-forge for installs
  * Add constructor for tuples during safe load
  * Fixes on URLs
  * one remaining dask.bytes
  * Test basic passing on of filesystems
  * Pass filesystem stuff through
  * Merge branch 'master' into fs
  * Remove unused import.
  * Refine temp_config_path fixutre.
  * Improve test coverage of discovery.
  * Fix name error exposed by testing.
  * Fix log call missing msg arg.
  * Fix typo.
  * Issue PendingDeprecationWarning for do_package_scan.
  * Document that do_package_scan will be changed and then removed.
  * Remove __future__ imports.
  * wget syntax
  * much simpler travis script
  * simple build
  * deps
  * simplify travis installs
  * fix up
  * Merge branch 'master' into fs
  * replace dask.bytes imports
  * Fix typo --- intended length check.
  * Add autodiscover_all and list non-enabled plugins.
  * Add module docstring.
  * Look for and log entrypoint name collision.
  * Fix typo (local var name changed).
  * Document interaction between package scan and entrypoint.
  * Use 'raise from'.
  * Issue FutureWarning for any package_scan_results.
  * Fix typos.
  * Include module in debug log messages.
  * Fix typo
  * Fix shadowing.
  * Add debug logs. Separate discovery and loading.
  * Remove another unused import.
  * Roll back unneeded changes.
  * Update 'Making Drivers' docs.
  * Finish conf integration; update CLI.
  * Incorporate 'drivers' section in config.
  * Make test_which more robust.
  * Incorporate 'intake.drivers' entrypoint.
  * Make enable/disable accessible from Python API.
  * Remove Python 2 compat.
  * Skip unreadable entries after logging error.
  * Remove usage of six. Use yaml_load util func.
  * Fix biffed rebase.
  * Refine help string.
  * Add drivers.d system and drivers subcommand.
  * Minor typo fix in the "Making Drivers" docs
  * move the {en|de}code_datetime to the compat.{pack|unpack}_kwargs
  * Provide ndim attribute for npy accessor
  * added test to check if datetime user_parameters work
  * add use case for upload
  * handle lack of tz info
  * add tests for coerce_datetime and handle non-iterable input
  * fix numpy warning, and future issue with elementwise comparison
  * rm errant print()
  * added {en|de}code_datetime to various msgpack.{packb|unpackb}
  * Change API
  * WIP: is this the right add source API?
  * copy is_dataframe_like
  * add to API docs
  * Add uppload function and machinery
  * explicit reference to nested cats in conda packages
  * Update talks
  * Working FS
  * Update use_cases.rst
  * fixes
  * Merge branch 'master' into params_editor
  * revert line
  * mid
  * start
  * fix tests
  * Hide plot when changing source selection
  * inatke-examples link
  * rst not md
  * Update links to intake-examples and include GUI blog
  * Refactor to make one less copy.
  * Avoid accidental mutation.
  * Storage options applied to wrong FS in compressed cache
  * Add GUI classes
  * Merge branch 'master' into more_api
  * Add classes
  * Let GUI docs be visible; don't ever error on repr
* Mon Jun  3 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.5.1
  * Making sure that catalog and entry guis work
  * Making sure that logo is always part of panel
  * A little paranoia in case describe() exposes mutable state.
  * Do not nest inside 'source' key twice.
  * Work on copy that will be serialized.
  * Apply to info-get route
  * Don't attempt to serialise functions in server response
  * Defer inputs until needed
  * add intake-stac to plugins list
  * Allow local cat entry to specify explicit driver class
  * In GUI code, use describe() rather than attrbiutes
  * make msgpack_numpy optional
  * Don't pop plots from metadata
  * Don't remove plots from description
  * Add intake-dcat to the plugin directory.
  * Serializing and deserializing state
  * Add name to describe(), standardize describe() and describe_open()
  * Fixing up done_callback switch
  * Allow the expannding and collapsing of nested catalogs
  * Disable buttons when they aren't ready
- Fix jupyter dependencies.
* Mon Jan 21 2019 Todd R <toddrme2178@gmail.com>
- Initial version
